@@ -22,13 +22,6 @@
 from functools import partial
 
 from astroid import (
-    MANAGER,
-    AstroidTypeError,
-    AttributeInferenceError,
-    InferenceError,
-    MroError,
-    NameInferenceError,
-    UseInferenceDefault,
     arguments,
     helpers,
     inference_tip,
@@ -38,6 +31,15 @@ from astroid import (
     util,
 )
 from astroid.builder import AstroidBuilder
+from astroid.exceptions import (
+    AstroidTypeError,
+    AttributeInferenceError,
+    InferenceError,
+    MroError,
+    NameInferenceError,
+    UseInferenceDefault,
+)
+from astroid.manager import AstroidManager
 
 OBJECT_DUNDER_NEW = "object.__new__"
 
@@ -126,7 +128,7 @@ class whatever(object):
 def _extend_string_class(class_node, code, rvalue):
     """function to extend builtin str/unicode class"""
     code = code.format(rvalue=rvalue)
-    fake = AstroidBuilder(MANAGER).string_build(code)["whatever"]
+    fake = AstroidBuilder(AstroidManager()).string_build(code)["whatever"]
     for method in fake.mymethods():
         method.parent = class_node
         method.lineno = None
@@ -138,7 +140,7 @@ def _extend_string_class(class_node, code, rvalue):
 
 
 def _extend_builtins(class_transforms):
-    builtin_ast = MANAGER.builtins_module
+    builtin_ast = AstroidManager().builtins_module
     for class_name, transform in class_transforms.items():
         transform(builtin_ast[class_name])
 
@@ -202,7 +204,7 @@ def register_builtin_transform(transform, builtin_name):
                 result.col_offset = node.col_offset
         return iter([result])
 
-    MANAGER.register_transform(
+    AstroidManager().register_transform(
         nodes.Call,
         inference_tip(_transform_wrapper),
         partial(_builtin_filter_predicate, builtin_name=builtin_name),
@@ -327,7 +329,7 @@ def _get_elts(arg, context):
 
     try:
         inferred = next(arg.infer(context))
-    except (InferenceError, NameInferenceError) as exc:
+    except (InferenceError, NameInferenceError, StopIteration) as exc:
         raise UseInferenceDefault from exc
     if isinstance(inferred, nodes.Dict):
         items = inferred.items
@@ -430,11 +432,11 @@ def infer_super(node, context=None):
     else:
         try:
             mro_pointer = next(node.args[0].infer(context=context))
-        except InferenceError as exc:
+        except (InferenceError, StopIteration) as exc:
             raise UseInferenceDefault from exc
         try:
             mro_type = next(node.args[1].infer(context=context))
-        except InferenceError as exc:
+        except (InferenceError, StopIteration) as exc:
             raise UseInferenceDefault from exc
 
     if mro_pointer is util.Uninferable or mro_type is util.Uninferable:
@@ -456,7 +458,7 @@ def _infer_getattr_args(node, context):
     try:
         obj = next(node.args[0].infer(context=context))
         attr = next(node.args[1].infer(context=context))
-    except InferenceError as exc:
+    except (InferenceError, StopIteration) as exc:
         raise UseInferenceDefault from exc
 
     if obj is util.Uninferable or attr is util.Uninferable:
@@ -494,7 +496,7 @@ def infer_getattr(node, context=None):
             # Try to infer the default and return it instead.
             try:
                 return next(node.args[2].infer(context=context))
-            except InferenceError as exc:
+            except (StopIteration, InferenceError) as exc:
                 raise UseInferenceDefault from exc
 
     raise UseInferenceDefault
@@ -542,7 +544,7 @@ def infer_callable(node, context=None):
     argument = node.args[0]
     try:
         inferred = next(argument.infer(context=context))
-    except InferenceError:
+    except (InferenceError, StopIteration):
         return util.Uninferable
     if inferred is util.Uninferable:
         return util.Uninferable
@@ -562,7 +564,7 @@ def infer_property(node, context=None):
     getter = node.args[0]
     try:
         inferred = next(getter.infer(context=context))
-    except InferenceError as exc:
+    except (InferenceError, StopIteration) as exc:
         raise UseInferenceDefault from exc
 
     if not isinstance(inferred, (nodes.FunctionDef, nodes.Lambda)):
@@ -590,7 +592,7 @@ def infer_bool(node, context=None):
     argument = node.args[0]
     try:
         inferred = next(argument.infer(context=context))
-    except InferenceError:
+    except (InferenceError, StopIteration):
         return util.Uninferable
     if inferred is util.Uninferable:
         return util.Uninferable
@@ -680,7 +682,7 @@ def infer_issubclass(callnode, context=None):
 
     try:
         obj_type = next(obj_node.infer(context=context))
-    except InferenceError as exc:
+    except (InferenceError, StopIteration) as exc:
         raise UseInferenceDefault from exc
     if not isinstance(obj_type, nodes.ClassDef):
         raise UseInferenceDefault("TypeError: arg 1 must be class")
@@ -747,13 +749,19 @@ def _class_or_tuple_to_container(node, context=None):
     # Move inferences results into container
     # to simplify later logic
     # raises InferenceError if any of the inferences fall through
-    node_infer = next(node.infer(context=context))
+    try:
+        node_infer = next(node.infer(context=context))
+    except StopIteration as e:
+        raise InferenceError(node=node, context=context) from e
     # arg2 MUST be a type or a TUPLE of types
     # for isinstance
     if isinstance(node_infer, nodes.Tuple):
-        class_container = [
-            next(node.infer(context=context)) for node in node_infer.elts
-        ]
+        try:
+            class_container = [
+                next(node.infer(context=context)) for node in node_infer.elts
+            ]
+        except StopIteration as e:
+            raise InferenceError(node=node, context=context) from e
         class_container = [
             klass_node for klass_node in class_container if klass_node is not None
         ]
@@ -863,7 +871,7 @@ def infer_dict_fromkeys(node, context=None):
     values = call.positional_arguments[0]
     try:
         inferred_values = next(values.infer(context=context))
-    except InferenceError:
+    except (InferenceError, StopIteration):
         return _build_dict_with_elements([])
     if inferred_values is util.Uninferable:
         return _build_dict_with_elements([])
@@ -923,7 +931,7 @@ register_builtin_transform(infer_dict_fromkeys, "dict.fromkeys")
 
 
 # Infer object.__new__ calls
-MANAGER.register_transform(
+AstroidManager().register_transform(
     nodes.ClassDef,
     inference_tip(_infer_object__new__decorator),
     _infer_object__new__decorator_check,
