@@ -7,17 +7,16 @@
 
 
 """Different utilities for the numpy brains"""
-
-
-import astroid
+from astroid.builder import extract_node
+from astroid.node_classes import Attribute, Import, Name, NodeNG
 
 
 def infer_numpy_member(src, node, context=None):
-    node = astroid.extract_node(src)
+    node = extract_node(src)
     return node.infer(context=context)
 
 
-def _is_a_numpy_module(node: astroid.node_classes.Name) -> bool:
+def _is_a_numpy_module(node: Name) -> bool:
     """
     Returns True if the node is a representation of a numpy module.
 
@@ -31,7 +30,7 @@ def _is_a_numpy_module(node: astroid.node_classes.Name) -> bool:
     """
     module_nickname = node.name
     potential_import_target = [
-        x for x in node.lookup(module_nickname)[1] if isinstance(x, astroid.Import)
+        x for x in node.lookup(module_nickname)[1] if isinstance(x, Import)
     ]
     for target in potential_import_target:
         if ("numpy", module_nickname) in target.names or (
@@ -42,9 +41,7 @@ def _is_a_numpy_module(node: astroid.node_classes.Name) -> bool:
     return False
 
 
-def looks_like_numpy_member(
-    member_name: str, node: astroid.node_classes.NodeNG
-) -> bool:
+def looks_like_numpy_member(member_name: str, node: NodeNG) -> bool:
     """
     Returns True if the node is a member of numpy whose
     name is member_name.
@@ -54,14 +51,14 @@ def looks_like_numpy_member(
     :return: True if the node is a member of numpy
     """
     if (
-        isinstance(node, astroid.Attribute)
+        isinstance(node, Attribute)
         and node.attrname == member_name
-        and isinstance(node.expr, astroid.Name)
+        and isinstance(node.expr, Name)
         and _is_a_numpy_module(node.expr)
     ):
         return True
     if (
-        isinstance(node, astroid.Name)
+        isinstance(node, Name)
         and node.name == member_name
         and node.root().name.startswith("numpy")
     ):
