@@ -20,10 +20,10 @@
 
 All nodes inherit from :class:`~astroid.node_classes.NodeNG`.
 """
-# pylint: disable=redefined-builtin
 
 # Nodes not present in the builtin ast module:  DictUnpack, Unknown, and EvaluatedObject.
-from astroid.node_classes import (
+
+from astroid.node_classes import (  # pylint: disable=redefined-builtin (Ellipsis)
     AnnAssign,
     Arguments,
     Assert,
@@ -53,7 +53,6 @@ from astroid.node_classes import (
     EmptyNode,
     EvaluatedObject,
     ExceptHandler,
-    Exec,
     Expr,
     ExtSlice,
     For,
@@ -79,11 +78,10 @@ from astroid.node_classes import (
     MatchValue,
     Name,
     NamedExpr,
+    NodeNG,
     Nonlocal,
     Pass,
-    Print,
     Raise,
-    Repr,
     Return,
     Set,
     Slice,
@@ -113,18 +111,18 @@ from astroid.scoped_nodes import (
 )
 
 ALL_NODE_CLASSES = (
-    AsyncFunctionDef,
-    AsyncFor,
-    AsyncWith,
-    Await,
+    AnnAssign,
     Arguments,
-    AssignAttr,
     Assert,
     Assign,
-    AnnAssign,
+    AssignAttr,
     AssignName,
+    AsyncFor,
+    AsyncFunctionDef,
+    AsyncWith,
+    Attribute,
     AugAssign,
-    Repr,
+    Await,
     BinOp,
     BoolOp,
     Break,
@@ -137,28 +135,28 @@ ALL_NODE_CLASSES = (
     Continue,
     Decorators,
     DelAttr,
-    DelName,
     Delete,
+    DelName,
     Dict,
     DictComp,
     DictUnpack,
-    Expr,
     Ellipsis,
     EmptyNode,
     EvaluatedObject,
     ExceptHandler,
-    Exec,
+    Expr,
     ExtSlice,
     For,
-    ImportFrom,
+    FormattedValue,
     FunctionDef,
-    Attribute,
     GeneratorExp,
     Global,
     If,
     IfExp,
     Import,
+    ImportFrom,
     Index,
+    JoinedStr,
     Keyword,
     Lambda,
     List,
@@ -173,12 +171,12 @@ ALL_NODE_CLASSES = (
     MatchSingleton,
     MatchStar,
     MatchValue,
+    Module,
     Name,
     NamedExpr,
+    NodeNG,
     Nonlocal,
-    Module,
     Pass,
-    Print,
     Raise,
     Return,
     Set,
@@ -195,6 +193,7 @@ ALL_NODE_CLASSES = (
     With,
     Yield,
     YieldFrom,
-    FormattedValue,
-    JoinedStr,
 )
+
+# Can't create a proper __all__ with string because of a cyclic import for ClassDef
+__all__ = [c.__name__ for c in ALL_NODE_CLASSES]
